import { css } from "@linaria/core";
import { omit } from "lodash";
import { defineComponent, onMounted, reactive, ref } from "vue";
import { any } from "vue-types";
import { useEditor } from "../../..";
import { Background, Layout } from "../../../typings";

export const View = defineComponent({
  props: {
    background: any<Background>(),
    layout: any<Layout>(),
  },
  setup(props, { slots }) {
    const { store, actions } = useEditor();
    const viewRef = ref<HTMLElement>();
    const state = reactive({
      compId: "",
    });
    onMounted(() => {
      const compEl = viewRef.value;
      state.compId = compEl?.getAttribute("data-id") || "";
    });
    return () => {
      const isComp = state.compId;
      const isSelected = store.isEditMode && store.currCompId === state.compId;

      const styleObj: any = {};
      if (props.background?.image) {
        styleObj["backgroundImage"] = `url(${props.background.image})`;
      } else if (props.background?.color) {
        styleObj["backgroundColor"] = props.background.color;
      }
      const bgOpts = Object.values(omit(props.background, ["image", "color"]));
      const bgClasses = bgOpts.length ? `bg-${bgOpts.join(" bg-")}` : "";

      return (
        <div
          ref={viewRef}
          class={[
            store.isEditMode && isComp ? viewStyle : "view_inside",
            store.isEditMode && isSelected && "view_selected",
            bgClasses,
          ]}
          style={styleObj}
          onClick={
            state.compId
              ? () => {
                  if (state.compId !== store.currCompId)
                    actions.pickCurrComp(state.compId);
                }
              : undefined
          }
        >
          {slots.default?.()}
        </div>
      );
    };
  },
});

const viewStyle = css`
  position: relative;
  &:hover {
    outline: 1px dashed @inf-primary-color;
  }

  > * {
    pointer-events: none;
  }

  &.view_selected {
    outline: 1px solid @inf-primary-color;

    > * {
      pointer-events: auto;
    }
    &::after {
      display: none;
    }

    .view_inside:hover {
      outline: 1px dashed @inf-primary-color;
      outline-offset: -1px;
    }
  }

  .view_inside {
    position: relative;
  }
`;
