import { defineUI } from "queenjs";
import { onUnmounted } from "vue";
import { Container, Draggable } from "vue-dndrop";
import { useEditor } from "../../..";
import { HotKeyCtrl } from "../../../controllers/HotKeyCtrl";
import Canvas from "../../Canvas";
import { View } from "../../CompUI/basicUI/View";

export default defineUI({
  setup() {
    const editor = useEditor();
    const { store, components, actions } = editor;

    const hotKeyCtrl = new HotKeyCtrl(editor);
    hotKeyCtrl.init();
    onUnmounted(() => {
      hotKeyCtrl.destroy();
    });

    return () => (
      <div class="min-h-750px bg-white">
        {store.isEditMode ? (
          <Container
            style={store.designData.pageStyle}
            onDrop={(e: any) => actions.moveComp(e.removedIndex, e.addedIndex)}
            non-drag-area-selector={".drag-disable"}
          >
            {store.designData.content.map((d) => {
              const Comp: any = components.CompUI[d.compKey];
              console.log(d);
              return (
                <Draggable key={d.id}>
                  <View
                    data-id={d.id}
                    class="draggable-item"
                    background={d.background}
                    layout={d.layout}
                  >
                    <Comp v-model={[d.value, "value"]} />
                  </View>
                </Draggable>
              );
            })}
          </Container>
        ) : (
          <Canvas />
        )}
      </div>
    );
  },
});
