import { useResource } from "@/modules/resource";
import { List } from "@queenjs/ui";
import { Button, Empty } from "ant-design-vue";
import { queenApi, useModal } from "queenjs";
import { defineComponent, reactive } from "vue";
import { useRoute } from "vue-router";

export default defineComponent({
  setup() {
    const resource = useResource();
    const modal = useModal();
    const route = useRoute();

    const state = reactive({
      list: [] as {id: string, qos:1}[],
    }) as any;

    const submit =async () => {
      if (state.list.length == 0) {
        queenApi.messageError("请选择至少一个模板");
        return;
      }
      const isOk = await resource.actions.submitRender(route.params.id as string, state.list, []);
      if (isOk) {
        modal.submit(true);
      }
    };

    return () => {
      return (
        <div>
          <List data={resource.store.sourceDetail.images} columns={5}>
            {{
              item: (record: any) => {
                return (
                  <resource.components.MaterialItem
                    record={record}
                    class="cursor-pointer"
                    active={ !!(state.list.find((v:any)=>v.id == record.id))}
                    onSelect={() => {
                      const selected =  !!(state.list.find((v:any)=>v.id == record.id))
                      if (selected) {
                        const index = state.list.findIndex(
                          (d: any) => d.id == record.id
                        );
                        state.list.splice(index);
                        return;
                      }
                      state.list.push({id: record.id, qos:1});
                    }}
                  />
                );
              },
              empty: () => <Empty description="暂无数据" />,
            }}
          </List>

          <div class="text-right">
            <Button onClick={modal.cancel}>取消</Button>
            <Button type="primary" class="ml-20px" onClick={submit}>
              确定
            </Button>
          </div>
        </div>
      );
    };
  },
});
